@@ -4,7 +4,7 @@ import csv
 import typing
 import datetime
 import json
-import warnings
+import logging
 
 
 def parse_path(path_str: str) -> Path:
@@ -17,7 +17,7 @@ def parse_path(path_str: str) -> Path:
     return p
 
 
-def detect_file_type(path_to_file: Path) -> str:
+def _detect_file_type(path_to_file: Path) -> str:
     """TODO sqlite Export integrieren -> unlocker mit bundlen (wie sieht das mit pypi aus?)"""
     dialect = None
 
@@ -52,10 +52,11 @@ def detect_file_type(path_to_file: Path) -> str:
         f.seek(0)
         df = pd.read_csv(f, dialect=dialect, skiprows=i, nrows=500)  # type: ignore
 
-    set_cols = set(df.columns)
+    logging.debug(f"csv dialect: {dialect}")
+    cols_set = set(df.columns)
 
     if (
-        set_cols
+        cols_set
         == set(
             [
                 "ID",
@@ -71,14 +72,14 @@ def detect_file_type(path_to_file: Path) -> str:
     ):
         return "sqlite_export"
 
-    if set_cols == set(["millis", "ax", "ay", "az", "trig"]) and i == 2:
+    if cols_set == set(["millis", "ax", "ay", "az", "trig"]) and i == 2:
         return "old_nanovib_recording"
 
-    if set_cols == set(["Axial", "Radial", "Torsional", "Trigger"]) and i == 3:
+    if cols_set == set(["Axial", "Radial", "Torsional", "Trigger"]) and i == 3:
         return "new_nanovib_recording"
 
     raise ValueError(
-        f"Unknown format, cols are {set_cols} and header is {i} lines long"
+        f"Unknown format, cols are {cols_set} and header is {i} lines long"
     )
 
 
@@ -105,14 +106,17 @@ def repair_file(p: typing.Union[Path, str]) -> Path:
     if not p.is_absolute():
         p = p.absolute()
 
-    file_type = detect_file_type(p)
+    file_type = _detect_file_type(p)
+    logging.info(f"detected file type: {file_type}")
 
     """ if parted measurmeent -> combine """
     if p.stem.endswith("0001"):
+        logging.info("Parted File detected, combining...")
         p_combined = p.parent / (p.stem[:-4] + "_combined" + p.suffix)
         p_part = p
         with open(p_combined, "w") as fw:
             while p_part.exists():
+                logging.debug(f"Partfile: {p_part}")
                 with open(p_part) as fr:
                     fw.write(fr.read())
 
@@ -122,6 +126,7 @@ def repair_file(p: typing.Union[Path, str]) -> Path:
                     p_part.stem[:-4] + str(i).zfill(4) + p_part.suffix
                 )
         p = p_combined
+        logging.info(f"combining completed! combined file: {p}")
     p_new = p.parent / (p.stem + "_fix.txt")
 
     dt_line = "None"
@@ -182,7 +187,7 @@ def repair_file(p: typing.Union[Path, str]) -> Path:
             settings = json.loads(settings_line)
             fs = int(1000 / (1 + settings["sensor"]["srd"]))
         except (json.JSONDecodeError, KeyError):
-            warnings.warn(
+            logging.warning(
                 "can't read settings json line of old nanovib recording using default samplerate of 500Hz"
             )
             fs = 500
@@ -204,14 +209,16 @@ def repair_file(p: typing.Union[Path, str]) -> Path:
 
     dt = datetime.datetime.min
     for dt_format in ["%d.%m.%Y %H:%M:%S", "%Y%m%d_%H%M%S"]:
+        logging.debug(f"trying datetime format: {dt_format}")
         try:
             dt = datetime.datetime.strptime(dt_line, dt_format)
+            logging.debug("Found!")
         except ValueError:
             pass
 
     if dt.year == datetime.datetime.min:
         if file_type != "sqlite_export":
-            warnings.warn(f"Date not recognised ({dt_line}), current dt used")
+            logging.warning(f"Date not recognised ({dt_line}), current dt used")
         dt = datetime.datetime.now()
 
     """ TODO Korrektur Achsen ermöglichen, wenn Torsional auf falscher Achse """
@@ -232,22 +239,31 @@ def repair_file(p: typing.Union[Path, str]) -> Path:
             except ValueError:
                 fs = 0
 
-    
     """ check and correction possibility of scaling """
     # df.rename(columns= {"Axial":"Torsional", "Torsional":"Axial"}, inplace=True)
     ax_mean = df["Axial"].mean()
     rad_mean = df["Radial"].mean()
     tor_mean = df["Torsional"].mean()
 
-    geo_mean = (ax_mean**2 + rad_mean**2 + tor_mean**2)**(1/2)
+    logging.info(f"Mean Values - Axial: {ax_mean:.2f}")
+    logging.info(f"Mean Values - Radial: {rad_mean:.2f}")
+    logging.info(f"Mean Values - Torsional: {tor_mean:.2f}")
+
+    geo_mean = (ax_mean**2 + rad_mean**2 + tor_mean**2) ** (1 / 2)
+
+    logging.info(f"Mean Values - Geometric: {geo_mean:.2f}")
     tor_ratio = abs(tor_mean) / geo_mean
 
+    logging.debug(f"Mean Values - Torsional Ratio: {tor_ratio:.2f}")
+
     if tor_ratio < 0.9:
         ax_ratio = abs(ax_mean) / geo_mean
         rad_ratio = abs(rad_mean) / geo_mean
         fitting_ax = "Axial" if ax_ratio > rad_ratio else "Radial"
 
-        print(f"Torsionsachse zeigt nicht nach unten, stattdessen wird {fitting_ax} genutzt.")
+        print(
+            f"Torsionsachse zeigt nicht nach unten, stattdessen wird {fitting_ax} genutzt."
+        )
         all_axes = {"Axial", "Radial", "Torsional"}
 
         nfa = list(all_axes - set([fitting_ax]))
@@ -260,17 +276,19 @@ def repair_file(p: typing.Union[Path, str]) -> Path:
         valid_input = False
         input_value = ""
         while not valid_input:
-            input_value = input(f"Welche Achse soll stattdessen für {fitting_ax} genutzt werden? ({nfa[0]} [1], {nfa[1]} [2]): ").lower()[0]
-            if input_value in ([c[0].lower() for c in nfa] + ["1","2"]):
+            input_value = input(
+                f"Welche Achse soll stattdessen für {fitting_ax} genutzt werden? ({nfa[0]} [1], {nfa[1]} [2]): "
+            ).lower()[0]
+            if input_value in ([c[0].lower() for c in nfa] + ["1", "2"]):
                 valid_input = True
 
         if input_value in ("1", "2"):
             i = int(input_value)
-            input_value = nfa[i-1].lower()
+            input_value = nfa[i - 1].lower()
 
         print(input_value)
         pass
-
+        """ TODO Achsenwechsel realisieren"""
 
     meas = (fs, dt, df)
     with open(p_new, "w") as fw:
@@ -278,19 +296,8 @@ def repair_file(p: typing.Union[Path, str]) -> Path:
         date_str = meas[1].strftime("%d.%m.%Y %H:%M:%S")
         fw.write(f"Start der Messung:\t{date_str}\n")
         fw.write("\n")
-        meas[2].to_csv(fw, index=False, sep="\t", lineterminator="\n", float_format="%.3f")
-        
+        meas[2].to_csv(
+            fw, index=False, sep="\t", lineterminator="\n", float_format="%.3f"
+        )
+
     return p_new
-
-
-if __name__ == "__main__":
-
-    path_str_list = [
-        # r"C:\Users\j.rose\Documents\ServerSync\GitHub\cpmax-toolbox\tests\test_files\20221025_151509\0001.txt",
-        # r"C:\Users\j.rose\Documents\ServerSync\GitHub\cpmax-toolbox\tests\test_files\Berching\output.csv",
-        r"C:\Users\j.rose\Documents\ServerSync\GitHub\cpmax-toolbox\tests\test_files\Gardelegen\20221025_103316.csv",
-        r"C:\Users\j.rose\Documents\ServerSync\GitHub\cpmax-toolbox\tests\test_files\Gardelegen\20221025_103316.txt",
-    ]
-
-    for p_str in path_str_list:
-        repair_file(p_str)
